.. _file_config.contrib:

Contrib
-------

.. automodule:: file_config.contrib.xml_parser
   :members:
   :private-members:
   :undoc-members:


.. automodule:: file_config.contrib.ini_parser
   :members:
   :private-members:
   :undoc-members:
